@@ -1,9 +1,10 @@
 /* varmon.c VA RAID Monitor (VARMon)
     
 Linux RAID Monitor for Mylex DAC960/1100 RAID controllers
-    
+
 Copyright 1999 by VA Linux Systems
-Author Dragan Stancevic <visitor@valinux.com>
+Original author Dragan Stancevic <visitor@valinux.com>
+Modification by Julien Danjou <julien@danjou.info>
     
 This program is free software; you may redistribute and/or modify it under
 the terms of the GNU General Public License Version 2 as published by the
@@ -26,17 +27,6 @@ sent directly to him for evaluation and testing.
 	
 	Thanks.
 */
-/*
-    
-I hope you find this software useful.
-    
-Send comments, suggestions and bug reports to visitor@valinux.com
-    
-Thanks.
-
---Dragan
-    
-*/
  
 #include <errno.h>
 #include <ctype.h>
@@ -146,14 +136,21 @@ int get_backplane_info(int what, SAFTE_T *safte, int controller, int cur_bp){
 	unsigned char *p;
 
 	char bus_n[] = "/dev/rd/c0d0";
+	char bus_n_devfs[] = "/dev/rd/disc0/disc";
 	char error_m[80];
 	char tr_data[1024];
 	DAC960_V1_DCDB_T dcdb;
 	
-	if((bus_h = open(bus_n, O_RDWR|O_NONBLOCK)) == -1){
+
+
+	if((bus_h = open(bus_n, O_RDWR|O_NONBLOCK)) == -1)
+	{
+	  if((bus_h = open(bus_n_devfs, O_RDWR|O_NONBLOCK)) == -1)
+	  {
 		sprintf(error_m, "\nFailed to open %s", bus_n);
 		perror(error_m);
 		exit(1);
+	  }
 	}
 	
 	memset(tr_data, 0, 1024);
@@ -427,11 +424,32 @@ int detect_backplane(){
 	DAC960_SCSI_Inquiry_T inq;
 	int num_controllers;
 	int controller_number;
-		char tmp[32];
+	char tmp[32];
+	struct utsname ut;
+
+	uname(&ut);
 	
-	if((fd = open("/dev/rd/c0d0", O_RDWR | O_NONBLOCK))<0){
+	/* If running 2.6 kernel */
+	if(!strncmp("2.6", ut.release, 3))
+	{
+	  if((fd = open("/dev/dac960_gam", O_RDWR | O_NONBLOCK)) < 0)
+	  {
 		printf("Unable to open device (%m)\n");
 		exit(1);
+	  }
+	}
+	/* 2.4 kernel */
+	else
+	{
+	  if((fd = open("/dev/rd/c0d0", O_RDWR | O_NONBLOCK))<0)
+	  {
+		/* devfs ? */
+		if((fd = open("/dev/rd/disc0/disc", O_RDWR | O_NONBLOCK))<0)
+		{
+		  printf("Unable to open device (%m)\n");
+		  exit(1);
+		}
+	  }
 	}
 	
 	num_controllers = ioctl(fd, DAC960_IOCTL_GET_CONTROLLER_COUNT, 0);
@@ -1811,7 +1829,8 @@ int get_stat(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int state_flag,
 --------------------------------------------------------------------------------
 	Interact with user*/
 void mv_fc(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int key_press, int no_cards){
-	int dummy = 0, dummy1 = 0, x = 0, card_focus = 0, tab_focus = 0;
+	int dummy = 0, x = 0, card_focus = 0, tab_focus = 0;
+	int dummy1 = 0;
 	char line[80];
 	
 	if(key_press != KEY_INIT){
@@ -2612,41 +2631,43 @@ void init_tab_pool(CARD *card_pool, TAB *tab_pool, int no_cards){
 --------------------------------------------------------------------------------
 	Trash UI at the end or in case of failure*/
 void trash_UI(SWINDOWS *all_win, int fail_stat){
-
-	switch(fail_stat){
-		case STATUS_WIN_FAIL:
-			goto status_fail;
-		case CARDLIST_FAIL:
-			goto cardlist_fail;
-		case TITLE_FAIL:
-			goto title_fail;
-		case BOTTOM_FAIL:
+   
+  switch(fail_stat)
+  {
+  case STATUS_WIN_FAIL:
+	goto status_fail;
+  case CARDLIST_FAIL:
+	goto cardlist_fail;
+  case TITLE_FAIL:
+	goto title_fail;
+  case BOTTOM_FAIL:
 			goto bottom_fail;
-		case TRASH_ALL:
-			goto trash_all;
-		case INIT_CARD_FAIL:
-			printf("\nDriver not comaptibble.\n");
-			goto init_card_fail;
-	}
-       
-	trash_all:
-		werase(all_win->status_win);
-		delwin(all_win->status_win);
-        status_fail:
-		werase(all_win->cardlist);
-        delwin(all_win->cardlist);
-        cardlist_fail:
-		werase(all_win->title);
-		delwin(all_win->title);
-        title_fail:
-		werase(all_win->bottom);
-		delwin(all_win->bottom);
-        bottom_fail:
-		werase(all_win->root);
-		refresh();
-        delwin(all_win->root);
-        endwin();
-	init_card_fail:
+  case TRASH_ALL:
+	goto trash_all;
+  case INIT_CARD_FAIL:
+	printf("\nDriver not compatible.\n");
+	goto init_card_fail;
+  }
+  
+ trash_all:
+  werase(all_win->status_win);
+  delwin(all_win->status_win);
+ status_fail:
+  werase(all_win->cardlist);
+  delwin(all_win->cardlist);
+ cardlist_fail:
+  werase(all_win->title);
+  delwin(all_win->title);
+ title_fail:
+  werase(all_win->bottom);
+  delwin(all_win->bottom);
+ bottom_fail:
+  werase(all_win->root);
+  refresh();
+  delwin(all_win->root);
+  endwin();
+ init_card_fail:
+  return;
 }
 
 /*
@@ -2743,7 +2764,7 @@ int build_UI(SWINDOWS *all_win, CARD *card_pool, TAB *tab_pool, int no_cards){
 			box(all_win->status_win,0,0);
 
 		        mvwaddstr(all_win->title, 0, ((COLS/2)-16), "=<| VA RAID Monitor (VARMon) |>="); 
-		        mvwaddstr(all_win->title, 1, ((COLS/2)-26), "Ver. 1.0.2 by Dragan Stancevic <visitor@valinux.com>"); 
+		        mvwaddstr(all_win->title, 1, ((COLS/2)-26), "Ver. 1.1.0 by Dragan Stancevic <visitor@valinux.com> / Julien Danjou <julien@danjou.info>"); 
 
 		        mvwaddstr(all_win->bottom, 0, 1, "<ESC> - Exit | <R> - Refresh | <RETURN> - Lock");
 		        mvwaddstr(all_win->cardlist, 0,1, "Detected cards");
